==> jc-1.4.0.tar.gz: java/awt/Choice__24AccessibleAWTChoice.h <==
// public class java.awt.Choice$AccessibleAWTChoice

// class file dependencies
// @dep_class 1b1cb48acd57c8ae java_awt_Choice__24AccessibleAWTChoice
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_Component__24AccessibleAWTComponent

#include "java/awt/Component__24AccessibleAWTComponent.h"

#ifndef _JC_java_awt_Choice__24AccessibleAWTChoice_H_
#define _JC_java_awt_Choice__24AccessibleAWTChoice_H_

// Forward structure declarations
struct _jc_java_awt_Choice$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_accessibility_AccessibleAction$object;
struct _jc_javax_accessibility_AccessibleRole$object;

// Typedefs
typedef struct _jc_java_awt_Choice__24AccessibleAWTChoice$sub_refs	_jc_java_awt_Choice__24AccessibleAWTChoice$sub_refs;
typedef struct _jc_java_awt_Choice__24AccessibleAWTChoice$sub_nonrefs	_jc_java_awt_Choice__24AccessibleAWTChoice$sub_nonrefs;
typedef struct _jc_java_awt_Choice__24AccessibleAWTChoice$refs	_jc_java_awt_Choice__24AccessibleAWTChoice$refs;
typedef struct _jc_java_awt_Choice__24AccessibleAWTChoice$nonrefs	_jc_java_awt_Choice__24AccessibleAWTChoice$nonrefs;
typedef struct _jc_java_awt_Choice__24AccessibleAWTChoice$object	_jc_java_awt_Choice__24AccessibleAWTChoice$object;

typedef struct _jc_java_awt_Choice__24AccessibleAWTChoice$fields_struct	_jc_java_awt_Choice__24AccessibleAWTChoice$fields_struct;
typedef const struct _jc_java_awt_Choice__24AccessibleAWTChoice$vmethods	_jc_java_awt_Choice__24AccessibleAWTChoice$vmethods;
typedef const struct _jc_java_awt_Choice__24AccessibleAWTChoice$vtable	_jc_java_awt_Choice__24AccessibleAWTChoice$vtable;
typedef const struct _jc_java_awt_Choice__24AccessibleAWTChoice$vtype	_jc_java_awt_Choice__24AccessibleAWTChoice$vtype;

// Class fields structure
struct _jc_java_awt_Choice__24AccessibleAWTChoice$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_Choice__24AccessibleAWTChoice$fields_struct _jc_java_awt_Choice__24AccessibleAWTChoice$class_fields;

// Constructors
extern void _jc_java_awt_Choice__24AccessibleAWTChoice$method$_init$ad44a9d0b673010b(_jc_env *, struct _jc_java_awt_Choice__24AccessibleAWTChoice$object *, struct _jc_java_awt_Choice$object *);

// Virtual methods
extern jboolean _jc_java_awt_Choice__24AccessibleAWTChoice$method$doAccessibleAction$1fa51348901e8b64(_jc_env *, struct _jc_java_awt_Choice__24AccessibleAWTChoice$object *, jint);
extern struct _jc_object *_jc_java_awt_Choice__24AccessibleAWTChoice$method$getAccessibleAction$41a543d228a6a159(_jc_env *, struct _jc_java_awt_Choice__24AccessibleAWTChoice$object *);
extern jint _jc_java_awt_Choice__24AccessibleAWTChoice$method$getAccessibleActionCount$53def32b00b4e336(_jc_env *, struct _jc_java_awt_Choice__24AccessibleAWTChoice$object *);
extern struct _jc_java_lang_String$object *_jc_java_awt_Choice__24AccessibleAWTChoice$method$getAccessibleActionDescription$45527bd1639e3985(_jc_env *, struct _jc_java_awt_Choice__24AccessibleAWTChoice$object *, jint);
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_java_awt_Choice__24AccessibleAWTChoice$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_java_awt_Choice__24AccessibleAWTChoice$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_Choice__24AccessibleAWTChoice$method_info$doAccessibleAction$1fa51348901e8b64;
extern _jc_method _jc_java_awt_Choice__24AccessibleAWTChoice$method_info$getAccessibleAction$41a543d228a6a159;
extern _jc_method _jc_java_awt_Choice__24AccessibleAWTChoice$method_info$getAccessibleActionCount$53def32b00b4e336;
extern _jc_method _jc_java_awt_Choice__24AccessibleAWTChoice$method_info$getAccessibleActionDescription$45527bd1639e3985;
extern _jc_method _jc_java_awt_Choice__24AccessibleAWTChoice$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_java_awt_Choice__24AccessibleAWTChoice$vmethods {
	jboolean	(*doAccessibleAction$1fa51348901e8b64)(_jc_env *, struct _jc_java_awt_Choice__24AccessibleAWTChoice$object *, jint);
	struct _jc_object	*(*getAccessibleAction$41a543d228a6a159)(_jc_env *, struct _jc_java_awt_Choice__24AccessibleAWTChoice$object *);
	jint	(*getAccessibleActionCount$53def32b00b4e336)(_jc_env *, struct _jc_java_awt_Choice__24AccessibleAWTChoice$object *);
	struct _jc_java_lang_String$object	*(*getAccessibleActionDescription$45527bd1639e3985)(_jc_env *, struct _jc_java_awt_Choice__24AccessibleAWTChoice$object *, jint);
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_java_awt_Choice__24AccessibleAWTChoice$object *);
};

// Vtable
struct _jc_java_awt_Choice__24AccessibleAWTChoice$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Choice__24AccessibleAWTChoice$vmethods	java_awt_Choice__24AccessibleAWTChoice;
};

// Vtype
struct _jc_java_awt_Choice__24AccessibleAWTChoice$vtype {
	_jc_type			type;
	_jc_java_awt_Choice__24AccessibleAWTChoice$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Choice__24AccessibleAWTChoice$sub_refs {
	struct _jc_java_awt_Choice$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Choice__24AccessibleAWTChoice$refs {
    _jc_java_awt_Choice__24AccessibleAWTChoice$sub_refs	java_awt_Choice__24AccessibleAWTChoice;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Choice__24AccessibleAWTChoice$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Choice__24AccessibleAWTChoice$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Choice__24AccessibleAWTChoice$sub_nonrefs	java_awt_Choice__24AccessibleAWTChoice;
};

// Object instance structure
struct _jc_java_awt_Choice__24AccessibleAWTChoice$object {
	_jc_java_awt_Choice__24AccessibleAWTChoice$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Choice__24AccessibleAWTChoice$vtype	*vtype;
	_jc_java_awt_Choice__24AccessibleAWTChoice$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Choice__24AccessibleAWTChoice$vtype _jc_java_awt_Choice__24AccessibleAWTChoice$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Choice__24AccessibleAWTChoice, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Choice__24AccessibleAWTChoice$class_object;

#endif	/* _JC_java_awt_Choice__24AccessibleAWTChoice_H_ */

==> jc-1.4.5.tar.gz: java/awt/Choice__24AccessibleAWTChoice.h <==
// public class java.awt.Choice$AccessibleAWTChoice

// class file dependencies
// @dep_class b5818d2026c752c0 java_awt_Choice__24AccessibleAWTChoice
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_Component__24AccessibleAWTComponent

#include "java/awt/Component__24AccessibleAWTComponent.h"

#ifndef _JC_java_awt_Choice__24AccessibleAWTChoice_H_
#define _JC_java_awt_Choice__24AccessibleAWTChoice_H_

// Forward structure declarations
struct _jc_java_awt_Choice$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_accessibility_AccessibleAction$object;
struct _jc_javax_accessibility_AccessibleRole$object;

// Typedefs
typedef struct _jc_java_awt_Choice__24AccessibleAWTChoice$sub_refs	_jc_java_awt_Choice__24AccessibleAWTChoice$sub_refs;
typedef struct _jc_java_awt_Choice__24AccessibleAWTChoice$sub_nonrefs	_jc_java_awt_Choice__24AccessibleAWTChoice$sub_nonrefs;
typedef struct _jc_java_awt_Choice__24AccessibleAWTChoice$refs	_jc_java_awt_Choice__24AccessibleAWTChoice$refs;
typedef struct _jc_java_awt_Choice__24AccessibleAWTChoice$nonrefs	_jc_java_awt_Choice__24AccessibleAWTChoice$nonrefs;
typedef struct _jc_java_awt_Choice__24AccessibleAWTChoice$object	_jc_java_awt_Choice__24AccessibleAWTChoice$object;

typedef struct _jc_java_awt_Choice__24AccessibleAWTChoice$fields_struct	_jc_java_awt_Choice__24AccessibleAWTChoice$fields_struct;
typedef const struct _jc_java_awt_Choice__24AccessibleAWTChoice$vmethods	_jc_java_awt_Choice__24AccessibleAWTChoice$vmethods;
typedef const struct _jc_java_awt_Choice__24AccessibleAWTChoice$vtable	_jc_java_awt_Choice__24AccessibleAWTChoice$vtable;
typedef const struct _jc_java_awt_Choice__24AccessibleAWTChoice$vtype	_jc_java_awt_Choice__24AccessibleAWTChoice$vtype;

// Class fields structure
struct _jc_java_awt_Choice__24AccessibleAWTChoice$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_Choice__24AccessibleAWTChoice$fields_struct _jc_java_awt_Choice__24AccessibleAWTChoice$class_fields;

// Constructors
extern void _jc_java_awt_Choice__24AccessibleAWTChoice$method$_init$ad44a9d0b673010b(_jc_env *, struct _jc_java_awt_Choice__24AccessibleAWTChoice$object *, struct _jc_java_awt_Choice$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_awt_Choice__24AccessibleAWTChoice$method$doAccessibleAction$1fa51348901e8b64(_jc_env *, struct _jc_java_awt_Choice__24AccessibleAWTChoice$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_awt_Choice__24AccessibleAWTChoice$method$getAccessibleAction$41a543d228a6a159(_jc_env *, struct _jc_java_awt_Choice__24AccessibleAWTChoice$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_Choice__24AccessibleAWTChoice$method$getAccessibleActionCount$53def32b00b4e336(_jc_env *, struct _jc_java_awt_Choice__24AccessibleAWTChoice$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_Choice__24AccessibleAWTChoice$method$getAccessibleActionDescription$45527bd1639e3985(_jc_env *, struct _jc_java_awt_Choice__24AccessibleAWTChoice$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_java_awt_Choice__24AccessibleAWTChoice$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_java_awt_Choice__24AccessibleAWTChoice$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_Choice__24AccessibleAWTChoice$method_info$doAccessibleAction$1fa51348901e8b64;
extern _jc_method _jc_java_awt_Choice__24AccessibleAWTChoice$method_info$getAccessibleAction$41a543d228a6a159;
extern _jc_method _jc_java_awt_Choice__24AccessibleAWTChoice$method_info$getAccessibleActionCount$53def32b00b4e336;
extern _jc_method _jc_java_awt_Choice__24AccessibleAWTChoice$method_info$getAccessibleActionDescription$45527bd1639e3985;
extern _jc_method _jc_java_awt_Choice__24AccessibleAWTChoice$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_java_awt_Choice__24AccessibleAWTChoice$vmethods {
	jboolean	(*doAccessibleAction$1fa51348901e8b64)(_jc_env *, struct _jc_java_awt_Choice__24AccessibleAWTChoice$object *, jint) _JC_JCNI_ATTR;
	struct _jc_object	*(*getAccessibleAction$41a543d228a6a159)(_jc_env *, struct _jc_java_awt_Choice__24AccessibleAWTChoice$object *) _JC_JCNI_ATTR;
	jint	(*getAccessibleActionCount$53def32b00b4e336)(_jc_env *, struct _jc_java_awt_Choice__24AccessibleAWTChoice$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getAccessibleActionDescription$45527bd1639e3985)(_jc_env *, struct _jc_java_awt_Choice__24AccessibleAWTChoice$object *, jint) _JC_JCNI_ATTR;
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_java_awt_Choice__24AccessibleAWTChoice$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_Choice__24AccessibleAWTChoice$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Choice__24AccessibleAWTChoice$vmethods	java_awt_Choice__24AccessibleAWTChoice;
};

// Vtype
struct _jc_java_awt_Choice__24AccessibleAWTChoice$vtype {
	_jc_type			type;
	_jc_java_awt_Choice__24AccessibleAWTChoice$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Choice__24AccessibleAWTChoice$sub_refs {
	struct _jc_java_awt_Choice$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Choice__24AccessibleAWTChoice$refs {
    _jc_java_awt_Choice__24AccessibleAWTChoice$sub_refs	java_awt_Choice__24AccessibleAWTChoice;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Choice__24AccessibleAWTChoice$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Choice__24AccessibleAWTChoice$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Choice__24AccessibleAWTChoice$sub_nonrefs	java_awt_Choice__24AccessibleAWTChoice;
};

// Object instance structure
struct _jc_java_awt_Choice__24AccessibleAWTChoice$object {
	_jc_java_awt_Choice__24AccessibleAWTChoice$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Choice__24AccessibleAWTChoice$vtype	*vtype;
	_jc_java_awt_Choice__24AccessibleAWTChoice$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Choice__24AccessibleAWTChoice$vtype _jc_java_awt_Choice__24AccessibleAWTChoice$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Choice__24AccessibleAWTChoice, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Choice__24AccessibleAWTChoice$class_object;

#endif	/* _JC_java_awt_Choice__24AccessibleAWTChoice_H_ */
